# Pypelines

## Description
Python command line tool to support CI/CD for various platforms

-- badges --

-- images --

## Installation

## Usage

## Support

## Roadmap

## Contributing

## Authors and Acknowledgements

## License
[MIT](https://choosealicense.com/licenses/mit/)